import { registerResponse } from './responses.js';
export const mockResponse = (db, responsesTable) => async (methodPathQuery, response, keep) => {
    const [method, pathWithQuery] = methodPathQuery.split(' ', 2);
    if (!/^[A-Z]+$/.test(method ?? ''))
        throw new Error(`Invalid method ${method} in ${methodPathQuery}!`);
    if (pathWithQuery === undefined)
        throw new Error(`Missing path in ${methodPathQuery}!`);
    const [path, query] = pathWithQuery.split('?', 2);
    if (path.startsWith('/'))
        throw new Error(`Path ${path} must not start with /!`);
    const bodyParts = [];
    if (response.headers !== undefined) {
        for (const [k, v] of response.headers.entries()) {
            bodyParts.push(`${k}: ${v}`);
        }
        bodyParts.push('');
    }
    if (response.body !== undefined)
        bodyParts.push(response.body);
    await registerResponse(db, responsesTable, {
        path,
        method: method ?? 'GET',
        queryParams: new URLSearchParams(query),
        body: bodyParts.length > 0 ? bodyParts.join('\n') : undefined,
        statusCode: response.status,
        keep,
    });
};
export const mock = ({ db, responsesTable, }) => ({
    response: mockResponse(db, responsesTable),
});
